@@ -3,7 +3,7 @@ from typing import List, Tuple
 
 from rich.prompt import Confirm
 
-from xklb import consts, db, play_actions, player, stats, tube_backend, utils
+from xklb import consts, db, play_actions, player, tube_backend, utils
 from xklb.consts import SC, DBType
 from xklb.utils import log
 
@@ -68,6 +68,10 @@ def parse_args(action, usage):
         if args.duration:
             args.duration = play_actions.parse_duration(args)
 
+        if not args.profile and not args.print:
+            print('Download profile must be specified. Use one of: --video --audio')
+            raise SystemExit(1)
+
     if args.db:
         args.database = args.db
     args.db = db.connect(args)
@@ -80,6 +84,7 @@ def parse_args(action, usage):
 
 def construct_query(args) -> Tuple[str, dict]:
     m_columns = args.db["media"].columns_dict
+    pl_columns = args.db["playlists"].columns_dict
 
     cf = []
     bindings = {}
@@ -93,10 +98,15 @@ def construct_query(args) -> Tuple[str, dict]:
 
     cf.append(
         f"""and cast(STRFTIME('%s',
-            datetime( time_modified, 'unixepoch', '+{args.retry_delay}')
+          datetime( time_modified, 'unixepoch', '+{args.retry_delay}')
         ) as int) < STRFTIME('%s', datetime()) """
     )
 
+    if "uploader" in m_columns:
+        cf.append(
+            f"and media.uploader not in (select uploader from playlists where category='{consts.BLOCK_THE_CHANNEL}')"
+        )
+
     args.sql_filter = " ".join(cf)
     args.sql_filter_bindings = bindings
 
@@ -105,23 +115,21 @@ def construct_query(args) -> Tuple[str, dict]:
             media.path
             {', playlist_path' if 'playlist_path' in m_columns else ''}
             , media.title
-            , media.duration
+            {', media.duration' if 'duration' in m_columns else ''}
             , media.time_created
-            , media.size
-            , coalesce(media.id, '') id
-            , p.dl_config
+            {', media.size' if 'size' in m_columns else ''}
+            {', media.id' if 'id' in m_columns else ''}
+            {', p.dl_config' if 'dl_config' in pl_columns else ''}
             , coalesce(p.category, p.ie_key) category
-            , p.profile
         FROM media
-        JOIN playlists p on {stats.get_playlists_join(args)}
+        JOIN playlists p on {db.get_playlists_join(args)}
         WHERE 1=1
-            and time_downloaded=0
+            and (media.time_downloaded=0 OR media.time_modified > media.time_downloaded)
             and media.time_deleted=0
             and p.time_deleted=0
             {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
             {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
             {args.sql_filter}
-            and media.uploader not in (select uploader from playlists where category='{consts.BLOCK_THE_CHANNEL}')
         ORDER BY 1=1
             {', ' + args.sort if args.sort else ''}
             , play_count
@@ -152,11 +160,7 @@ def dl_download(args=None) -> None:
 
     args = parse_args(
         SC.download,
-        usage=r"""library download database [--prefix /mnt/d/]
-
-    Tube and download databases are designed to be cross-compatible, but you will need to
-    run dladd once first with a valid URL for the extra dl columns to be added.
-    The supplied download profile and category of that first run will be copied to the existing rows.
+        usage=r"""library download database [--prefix /mnt/d/] --video | --audio
 
     Download stuff in a random order.
 
@@ -184,13 +188,16 @@ def dl_download(args=None) -> None:
     Print download queue groups
 
         library dlstatus audio.db
-        ╒════════════════╤═════════╤═══════════════════════════════════════════╤══════════╤══════════════╤═══════════╕
-        │ duration       │   count │ errors                                    │ ie_key   │ category     │ profile   │
-        ╞════════════════╪═════════╪═══════════════════════════════════════════╪══════════╪══════════════╪═══════════╡
-        │ 7 months, 5    │   36817 │ ERROR: [youtube]: No video formats found! │ Youtube  │ 81_New_Music │ audio     │
-        │ days, 1 hour   │         │                                           │          │              │           │
-        │ and 48 minutes │         │                                           │          │              │           │
-        ╘════════════════╧═════════╧═══════════════════════════════════════════╧══════════╧══════════════╧═══════════╛
+        ╒═════════════════════╤════════════╤══════════════════╤════════════════════╤══════════╕
+        │ category            │ ie_key     │ duration         │   never_downloaded │   errors │
+        ╞═════════════════════╪════════════╪══════════════════╪════════════════════╪══════════╡
+        │ 81_New_Music        │ Soundcloud │                  │                 10 │        0 │
+        ├─────────────────────┼────────────┼──────────────────┼────────────────────┼──────────┤
+        │ 81_New_Music        │ Youtube    │ 10 days, 4 hours │                  1 │     2555 │
+        │                     │            │ and 20 minutes   │                    │          │
+        ├─────────────────────┼────────────┼──────────────────┼────────────────────┼──────────┤
+        │ Playlist-less media │ Youtube    │ 7.68 minutes     │                 99 │        1 │
+        ╘═════════════════════╧════════════╧══════════════════╧════════════════════╧══════════╛
     """,
     )
     media = process_downloadqueue(args)
@@ -205,18 +212,11 @@ def dl_download(args=None) -> None:
             log.info("[%s]: Already downloaded. Skipping!", m["path"])
             continue
 
-        if m.get("profile") is None:
-            m["profile"] = DBType.video
-
-        if m["profile"] in (DBType.audio, DBType.video):
+        if args.profile in (DBType.audio, DBType.video):
             tube_backend.yt(args, m)
-        # elif m['profile'] == DBType.image:
         else:
             raise NotImplementedError
 
-    if not args.print:
-        db.optimize(args)
-
 
 def dl_block(args=None) -> None:
     if args:
@@ -249,7 +249,7 @@ def dl_block(args=None) -> None:
 
     if args.playlists:
         with args.db.conn:
-            args.db.execute(
+            args.db.conn.execute(
                 f"""UPDATE playlists
                 SET time_deleted={consts.NOW}
                 ,   category='{consts.BLOCK_THE_CHANNEL}'
