@@ -1,11 +1,16 @@
 import argparse, asyncio, queue, sqlite3, threading
 from pathlib import Path
 
-import aiohttp, requests
+import requests
 
 from xklb import db, utils
 from xklb.utils import log
 
+try:
+    import aiohttp
+except ModuleNotFoundError:
+    aiohttp = None
+
 """
 My understanding of aiohttp is stolen
 from ashish01's excellent https://github.com/ashish01/hn-data-dumps/blob/main/hn_async2.py
@@ -47,7 +52,7 @@ def parse_args(prog, usage) -> argparse.Namespace:
     parser.add_argument("--verbose", "-v", action="count", default=0)
     parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
 
-    parser.add_argument("database", nargs="*", default="hn.db")
+    parser.add_argument("database", nargs="?", default="hn.db")
     args = parser.parse_args()
 
     if args.db:
@@ -60,7 +65,8 @@ def parse_args(prog, usage) -> argparse.Namespace:
 
 
 def db_worker(args, input_queue):
-    db_conn = db.connect(args, args.database)
+    conn = sqlite3.connect(args.database, isolation_level=None)
+    db_conn = db.connect(args, conn)
     while True:
         r = input_queue.get()
         if r is None:
@@ -70,8 +76,8 @@ def db_worker(args, input_queue):
         db_conn["hn_" + hn_type].insert(data, pk="id", alter=True)  # type: ignore
 
 
-async def get_hn_item(session, db_queue, sem, id):
-    url = f"https://hacker-news.firebaseio.com/v0/item/{id}.json"
+async def get_hn_item(session, db_queue, sem, hn_id):
+    url = f"https://hacker-news.firebaseio.com/v0/item/{hn_id}.json"
     try:
         async with session.get(url) as response:
             data = await response.json()
@@ -120,6 +126,11 @@ def hacker_news_add() -> None:
         library hnadd --oldest --resume hn.db
     """,
     )
+    if aiohttp is None:
+        raise ModuleNotFoundError(
+            "aiohttp is required for hn_extract. Install with pip install aiohttp or pip install xklb[full]"
+        )
+
     args.db.enable_wal()
 
     args.latest_id = get("https://hacker-news.firebaseio.com/v0/maxitem.json")
@@ -138,6 +149,7 @@ def hacker_news_add() -> None:
                     {'UNION ALL SELECT id FROM hn_job' if 'hn_job' in tables else ''}
                     {'UNION ALL SELECT id FROM hn_poll' if 'hn_poll' in tables else ''}
                     {'UNION ALL SELECT id FROM hn_pollopt' if 'hn_pollopt' in tables else ''}
+                    {'UNION ALL SELECT ' + str(args.latest_id)}
                 )
             )
             SELECT * FROM t
@@ -147,6 +159,8 @@ def hacker_news_add() -> None:
         )
         args.latest_id = r["latest_id"]
         args.oldest_id = r["oldest_id"]
+        if args.latest_id == args.oldest_id:
+            raise SystemExit(128)
 
     db_queue = queue.Queue()
     db_thread = threading.Thread(target=db_worker, args=(args, db_queue))
@@ -156,7 +170,8 @@ def hacker_news_add() -> None:
     db_queue.put(None)
     db_thread.join()
 
-    db.optimize(args)
+    if (args.latest_id - args.oldest_id) > 100000:
+        db.optimize(args)
 
 
 if __name__ == "__main__":
