@@ -4,11 +4,11 @@ import scripts
 from xklb import utils
 from xklb.consts import SC
 from xklb.dl_extract import dl_block, dl_download
-from xklb.fs_extract import main as fs_add
+from xklb.fs_extract import fs_add, fs_update
 from xklb.hn_extract import hacker_news_add
 from xklb.play_actions import filesystem, listen, read, view, watch
 from xklb.playback import playback_next, playback_now, playback_pause, playback_stop
-from xklb.praw_extract import reddit_add
+from xklb.praw_extract import reddit_add, reddit_update
 from xklb.stats import dlstatus, playlists
 from xklb.tabs_actions import tabs
 from xklb.tabs_extract import tabs_add
@@ -17,43 +17,54 @@ from xklb.utils import log
 
 
 def usage() -> str:
-    return """xk media library [lb]
+    return """xk media library subcommands
 
-    local media subcommands:
-        fsadd                        Create a local media database; Add folders
-        listen                       Listen to local and online media
-        watch                        Watch local and online media
-        read                         Read books
-        view                         View images
-        filesystem                   Browse files
-        bigdirs                      Discover folders which take much room
-        dedupe                       Deduplicate audio files
-        christen                     Cleanse files by giving them a new name
+    local media:
+      lb fsadd                 Create a local media database; Add folders
+      lb fsupdate              Refresh database: add new files, mark deleted
 
-    online media subcommands:
-        tubeadd                      Create a tube database; Add playlists
-        tubeupdate                   Add new videos from saved playlists
-        redditadd                    Create a reddit database; Add subreddits
-        hnadd                        Create a hackernews database
+      lb listen                Listen to local and online media
+      lb watch                 Watch local and online media
 
-    download subcommands:
-        download                     Download media
-        block                        Prevent downloading specific URLs
-        merge-online-local           Merge local and online metadata
+      lb bigdirs               Discover folders which take much room
+      lb dedupe                Deduplicate audio files
+      lb christen              Cleanse files by giving them a new name
 
-    statistics subcommands:
-        playlists                    List added playlists
-        dlstatus                     Show download status
+      lb read                  Read books
+      lb view                  View images
 
-    playback subcommands:
-        now                          Print what is currently playing
-        next                         Play next file
-        stop                         Stop all playback
-        pause                        Pause all playback
+    online media:
+      lb tubeadd               Create a tube database; Add playlists
+      lb tubeupdate            Fetch new videos from saved playlists
 
-    browser tab subcommands:
-        tabsadd                      Create a tabs database; Add URLs
-        tabs                         Open your tabs for the day
+      lb redditadd             Create a reddit database; Add subreddits
+      lb redditupdate          Fetch new posts from saved subreddits
+
+    downloads:
+      lb download              Download media
+      lb block                 Prevent downloading specific URLs
+      lb merge-online-local    Merge local and online metadata
+
+    playback:
+      lb now                   Print what is currently playing
+      lb next                  Play next file
+      lb stop                  Stop all playback
+      lb pause                 Pause all playback
+
+    statistics:
+      lb playlists             List added playlists
+      lb dlstatus              Show download status
+
+    browser tabs:
+      lb tabsadd               Create a tabs database; Add URLs
+      lb tabs                  Open your tabs for the day
+      lb surf                  Load browser tabs in a streaming way (stdin)
+
+    mining:
+      lb pushshift             Convert Pushshift jsonl.zstd to reddit.db format
+      lb reddit-selftext       Save stored selftext external links to media table
+      lb hnadd                 Create a hackernews database
+      lb nfb-films             Director links -> film links (stdin)
     """
 
 
@@ -90,8 +101,10 @@ def lb(args=None) -> None:
         add_help=False,
     )
     subparsers = parser.add_subparsers()
-    subp_extract = add_parser(subparsers, "fsadd", ["x", "extract"])
-    subp_extract.set_defaults(func=fs_add)
+    subp_fsadd = add_parser(subparsers, "fsadd", ["x", "extract"])
+    subp_fsadd.set_defaults(func=fs_add)
+    subp_fsupdate = add_parser(subparsers, "fsupdate", ["xu"])
+    subp_fsupdate.set_defaults(func=fs_update)
 
     subp_watch = add_parser(subparsers, SC.watch, ["wt", "tubewatch", "tw", "entries"])
     subp_watch.set_defaults(func=watch)
@@ -124,6 +137,11 @@ def lb(args=None) -> None:
 
     subp_redditadd = add_parser(subparsers, "redditadd", ["ra", "xr"])
     subp_redditadd.set_defaults(func=reddit_add)
+    subp_redditupdate = add_parser(subparsers, "redditupdate", ["ru", "xru"])
+    subp_redditupdate.set_defaults(func=reddit_update)
+    subp_pushshift = add_parser(subparsers, "pushshift", ['ps'])
+    subp_pushshift.set_defaults(func=scripts.pushshift_extract)
+
     subp_hnadd = add_parser(subparsers, "hnadd")
     subp_hnadd.set_defaults(func=hacker_news_add)
 
@@ -150,6 +168,13 @@ def lb(args=None) -> None:
     subp_tabsadd.set_defaults(func=tabs_add)
     subp_tabs = add_parser(subparsers, "tabs", ["tb"])
     subp_tabs.set_defaults(func=tabs)
+    subp_surf = add_parser(subparsers, "surf", ["browse", "load"])
+    subp_surf.set_defaults(func=scripts.streaming_tab_loader)
+
+    subp_reddit_selftext = add_parser(subparsers, "reddit-selftext", ["rst"])
+    subp_reddit_selftext.set_defaults(func=scripts.parse_reddit_selftext)
+    subp_nfb_directors = add_parser(subparsers, "nfb-films")
+    subp_nfb_directors.set_defaults(func=scripts.nfb_films)
 
     parser.add_argument("--version", "-V", action="store_true")
     args, _unk = parser.parse_known_args(args)
