@@ -51,7 +51,8 @@ def construct_query(args) -> Tuple[str, dict]:
                 args.sort = "random(), " + args.sort
             else:
                 limit = consts.DEFAULT_PLAY_QUEUE * 16
-        cf.append(f"and rowid in (select rowid from media order by random() limit {limit})")
+        if 'limit' not in args.defaults:
+            cf.append(f"and rowid in (select rowid from media order by random() limit {limit})")
 
     args.sql_filter = " ".join(cf)
     args.sql_filter_bindings = bindings
@@ -405,6 +406,10 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     args.action = action
     args.defaults = []
 
+    if args.db:
+        args.database = args.db
+    args.db = db.connect(args)
+
     if not args.limit:
         args.defaults.append("limit")
         if all([not args.print, args.action in (SC.listen, SC.watch, SC.read)]):
@@ -414,25 +419,29 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     elif args.limit in ("inf", "all"):
         args.limit = None
 
-    if not args.sort:
-        args.defaults.append("sort")
-
-        if args.action in (SC.listen, SC.watch):
-            args.sort = ["priority"]
-            if args.include:
-                args.sort = ["duration desc", "size desc"]
-                if args.print:
-                    args.sort = ["duration", "size"]
-
-        elif args.action in (SC.filesystem):
-            args.sort = ["sparseness", "size"]
-
     if args.sort:
-        if args.play_in_order > 0:
-            args.sort.append("path")
+        args.sort = " ".join(args.sort).split(",")
+    elif not args.sort:
+        args.defaults.append("sort")
+        columns = args.db["media"].columns_dict
 
-        args.sort = ",".join(args.sort).replace(",,", ",")
-        args.sort = override_sort(args.sort)
+        args.sort = []
+        if args.action in (SC.filesystem):
+            args.sort.extend(["sparseness", "size"])
+        elif args.action in (SC.listen, SC.watch):
+            if "play_count" in columns:
+                args.sort.append("play_count")
+            if "size" in columns and "duration" in columns:
+                args.sort.append("ntile(1000) over (order by size/duration) desc")
+                if args.include:
+                    args.sort = ["duration desc", "size desc"]
+                    if args.print:
+                        args.sort = ["duration", "size"]
+
+    if args.play_in_order > 0:
+        args.sort.append("path")
+    args.sort = ",".join(args.sort).replace(",,", ",")
+    args.sort = override_sort(args.sort)
 
     if args.cols:
         args.cols = list(utils.flatten([s.split(",") for s in args.cols]))
@@ -450,9 +459,6 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     if args.player:
         args.player = shlex.split(args.player)
 
-    if args.db:
-        args.database = args.db
-    args.db = db.connect(args)
     log.info(utils.dict_filter_bool(args.__dict__))
 
     args.sock = None
@@ -521,7 +527,7 @@ def play(args, m: Dict) -> None:
         if args.transcode:
             media_file = transcode(media_file)
 
-    if args.action == SC.listen:
+    if args.action == SC.listen and not media_file.startswith("http"):
         print(cmd("ffprobe", "-hide_banner", "-loglevel", "info", media_file).stderr)
     else:
         print(media_file)
@@ -567,7 +573,7 @@ def process_playqueue(args) -> None:
     if not media:
         utils.no_media_found()
 
-    if all([Path(args.watch_later_directory).exists(), args.play_in_order != 2, "sort" in args.defaults]):
+    if all([Path(args.watch_later_directory).exists(), args.play_in_order <= 1, "sort" in args.defaults]):
         media = utils.mpv_enrich(args, media)
 
     if args.multiple_playback:
