@@ -39,7 +39,7 @@ def generic_player(args) -> List[str]:
 
 def calculate_duration(args, m) -> Tuple[int, int]:
     start = 0
-    end = m["duration"]
+    end = m.get("duration", 0)
 
     if args.start:
         if args.start == "wadsworth":
@@ -173,9 +173,9 @@ def mark_media_watched(args, files) -> int:
             with args.db.conn:
                 cursor = args.db.conn.execute(
                     """UPDATE media
-                    set play_count = play_count +1
+                    SET play_count = play_count + 1
                     , time_played = cast(STRFTIME('%s') as int)
-                    where path in ("""
+                    WHERE path in ("""
                     + ",".join(["?"] * len(l))
                     + ")",
                     (*l,),
@@ -274,7 +274,6 @@ def override_sort(sort_expression: str) -> str:
         sort_expression.replace("month_created", YEAR_MONTH("time_created"))
         .replace("month_modified", YEAR_MONTH("time_modified"))
         .replace("random", "random()")
-        .replace("priority", " play_count, ntile(1000) over (order by size/duration) desc")
     )
 
 
@@ -287,6 +286,9 @@ def get_ordinal_media(args, path: str) -> str:
     candidate = deepcopy(path)
     similar_videos = []
     while len(similar_videos) < 2:
+        if candidate == '':
+            return path
+
         remove_groups = re.split(r"([\W]+|\s+|Ep\d+|x\d+|\.\d+)", candidate)
         log.debug(remove_groups)
         remove_chars = ""
@@ -307,7 +309,7 @@ def get_ordinal_media(args, path: str) -> str:
                 and path like :candidate
                 {'and time_deleted=0' if 'time_deleted' in columns else ''}
                 {'' if (args.play_in_order >= 3) else (args.sql_filter or '')}
-            ORDER BY path
+            ORDER BY play_count, path
             LIMIT 1000
             """
         bindings = {"candidate": "%" + candidate + "%"}
