@@ -1,6 +1,7 @@
 import argparse
 import datetime as dt
-import typing
+import json
+import sys
 from functools import partial
 from itertools import takewhile
 from pathlib import Path
@@ -9,7 +10,6 @@ from typing import Any, Dict, Optional
 import praw, prawcore
 
 from xklb import consts, db, utils
-from xklb.consts import DBType
 from xklb.utils import log
 
 PRAW_SETUP_INSTRUCTIONS = r"""
@@ -66,6 +66,8 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+skip_errors = (prawcore.exceptions.NotFound, prawcore.exceptions.Forbidden, prawcore.exceptions.Redirect)
+
 
 def created_since(row: Any, target_sec_utc: Optional[int]) -> bool:
     result = (not target_sec_utc) or (row.created_utc >= target_sec_utc)
@@ -82,7 +84,7 @@ def legalize(val: Any) -> Any:
     return val
 
 
-def _parent_ids_interpreted(dct: typing.Dict[str, typing.Any]) -> Dict[str, typing.Any]:
+def _parent_ids_interpreted(dct: Dict[str, Any]) -> Dict[str, Any]:
     if not dct.get("parent_id"):
         return dct
 
@@ -95,12 +97,13 @@ def _parent_ids_interpreted(dct: typing.Dict[str, typing.Any]) -> Dict[str, typi
     return dct
 
 
-def saveable(item: Any) -> Dict[str, typing.Any]:
+def saveable(item: Any) -> Dict[str, Any]:
     result = {k: legalize(v) for k, v in item.__dict__.items() if not k.startswith("_")}
     return _parent_ids_interpreted(result)
 
 
-def slim_post_data(d: dict, playlist_path) -> dict:
+
+def slim_post_data(d: dict, playlist_path=None) -> dict:
     skip_domains = ["linktr.ee", "twitter.com", "t.me", "patreon", "onlyfans", "fans.ly", "file-upload", "file-link"]
     overridden_url = (
         d.get("url_overridden_by_dest") if any([domain in d["url"].lower() for domain in skip_domains]) else d["url"]
@@ -114,7 +117,6 @@ def slim_post_data(d: dict, playlist_path) -> dict:
         "is_over_18": d.get("over_18"),
         "is_archived": d.get("archived"),
         "is_original_content": d.get("is_original_content"),
-        "is_reddit_media_domain": d.get("is_reddit_media_domain"),
         "is_self": d.get("is_self"),
         "is_video": d.get("is_video"),
         "link_flair_text": d.get("link_flair_text"),
@@ -129,9 +131,10 @@ def slim_post_data(d: dict, playlist_path) -> dict:
     }
 
 
-def save_post(args, subreddit_path, post_dict):
-    author_is_blocked = post_dict["author_is_blocked"]
-    selftext_html = post_dict["selftext_html"]
+
+def save_post(args, post_dict, subreddit_path):
+    author_is_blocked = post_dict.get("author_is_blocked")
+    selftext_html = post_dict.get("selftext_html")
     slim_dict = utils.dict_filter_bool(slim_post_data(post_dict, subreddit_path))
 
     if slim_dict:
@@ -143,6 +146,21 @@ def save_post(args, subreddit_path, post_dict):
         if already_downloaded_path:
             slim_dict["path"] = already_downloaded_path
 
+        existing_meta = args.db.pop_dict(
+            "SELECT * FROM media WHERE path =?",
+            [slim_dict["path"]],
+            ignore_errors=["no such column", "no such table"],
+        )
+
+        slim_dict = {
+            **slim_dict,
+            "play_count": 0,
+            "time_played": 0,
+            "time_downloaded": 0,
+            "time_deleted": 0,
+            **(existing_meta or {}),
+        }
+
         if author_is_blocked == 1:
             pass
         elif selftext_html:
@@ -164,12 +182,14 @@ def since_last_created(args, playlist_path):
     """,
         [playlist_path],
     )
-    if latest_post_utc is None:
-        log.debug("Using NOW")
-        latest_post_utc = consts.NOW
-    get_since = dt.datetime.fromtimestamp(latest_post_utc) - dt.timedelta(days=args.lookback)
-    get_since = int(get_since.timestamp())
-    log.info("Getting posts since timestamp %s", get_since)
+    if latest_post_utc:
+        get_since = dt.datetime.fromtimestamp(latest_post_utc) - dt.timedelta(days=args.lookback)
+        get_since = int(get_since.timestamp())
+        log.info("Getting posts since timestamp %s", get_since)
+    else:
+        get_since = 0
+        log.info("Getting posts since the dawn of time...")
+
     _takewhile = partial(created_since, target_sec_utc=get_since)
     return _takewhile
 
@@ -183,7 +203,7 @@ def redditor_new(args, redditor_dict) -> None:
 
     for s in takewhile(_takewhile, user.submissions.new(limit=args.limit)):
         s.time_created = s.created_utc
-        save_post(args, user_path, saveable(s))
+        save_post(args, saveable(s), user_path)
 
 
 def subreddit_new(args, subreddit_dict) -> None:
@@ -208,7 +228,7 @@ def subreddit_new(args, subreddit_dict) -> None:
                 alter=True,
             )
 
-        save_post(args, subreddit_path, post_dict)
+        save_post(args, post_dict, subreddit_path)
 
 
 def subreddit_top(args, subreddit_dict) -> None:
@@ -225,52 +245,72 @@ def subreddit_top(args, subreddit_dict) -> None:
     for time_filter in time_filters:
         log.info("Getting top posts in %s for time_filter '%s'", subreddit, time_filter)
         for post in takewhile(_takewhile, subreddit.top(time_filter, limit=args.limit)):
-            save_post(args, subreddit_path, saveable(post))
+            save_post(args, saveable(post), subreddit_path)
 
 
-def parse_args(prog, usage) -> argparse.Namespace:
-    parser = argparse.ArgumentParser(prog, usage)
-    parser.add_argument("--limit", default=1000)
+def parse_args(action, usage) -> argparse.Namespace:
+    parser = argparse.ArgumentParser(prog="library " + action, usage=usage)
+    parser.add_argument("--limit", default=1000, type=int)
     parser.add_argument("--lookback", default=4, type=int, help="Number of days to look back")
     parser.add_argument("--praw-site", default="bot1")
 
     parser.add_argument("--subreddits", action="store_true")
     parser.add_argument("--redditors", action="store_true")
 
-    subp_profile = parser.add_mutually_exclusive_group()
-    subp_profile.add_argument(
-        "--audio", "-A", action="store_const", dest="profile", const=DBType.audio, help="Use audio downloader"
-    )
-    subp_profile.add_argument(
-        "--video", "-V", action="store_const", dest="profile", const=DBType.video, help="Use video downloader"
-    )
-    subp_profile.add_argument(
-        "--image", "-I", action="store_const", dest="profile", const=DBType.image, help="Use image downloader"
-    )
-    subp_profile.set_defaults(profile=DBType.video)
-
     parser.add_argument("--category", "-c", help=argparse.SUPPRESS)
 
     parser.add_argument("--verbose", "-v", action="count", default=0)
     parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
 
     parser.add_argument("database", nargs="?", default="reddit.db")
-    parser.add_argument("paths", nargs="+")
+    if action == "redditadd":
+        parser.add_argument("paths", nargs="+")
     args = parser.parse_args()
 
+    if action == "redditadd":
+        args.paths = utils.conform(args.paths)
+
     if args.db:
         args.database = args.db
     Path(args.database).touch()
     args.db = db.connect(args)
-    args.paths = utils.conform(args.paths)
+
+    try:
+        args.reddit = praw.Reddit(args.praw_site, config_interpolation="basic")
+    except Exception as e:
+        print(PRAW_SETUP_INSTRUCTIONS)
+        raise SystemExit(e)
+
     log.info(utils.dict_filter_bool(args.__dict__))
 
     return args
 
 
-def reddit_add() -> None:
+def process_redditors(args, redditors):
+    for redditor in redditors:
+        try:
+            redditor_new(args, redditor)
+        except skip_errors as e:
+            log.error("[%s] skipping redditor: %s", redditor["name"], e)
+            continue
+
+
+def process_subreddits(args, subreddits):
+    for subreddit in subreddits:
+        try:
+            subreddit_new(args, subreddit)
+            subreddit_top(args, subreddit)
+        except skip_errors as e:
+            log.error("[%s] skipping subreddit: %s", subreddit["name"], e)
+            continue
+
+
+def reddit_add(args=None) -> None:
+    if args:
+        sys.argv[1:] = args
+
     args = parse_args(
-        prog="library redditadd",
+        "redditadd",
         usage="""library redditadd [--lookback N_DAYS] [--praw-site bot1] [database] paths ...
 
     Fetch data for redditors and reddits:
@@ -287,12 +327,6 @@ def reddit_add() -> None:
     """,
     )
 
-    try:
-        args.reddit = praw.Reddit(args.praw_site, config_interpolation="basic")
-    except Exception as e:
-        print(PRAW_SETUP_INSTRUCTIONS)
-        raise SystemExit(e)
-
     subreddits = []
     redditors = []
     for path in args.paths:
@@ -311,10 +345,12 @@ def reddit_add() -> None:
         else:
             if args.subreddits:
                 ie_key = "reddit_praw_subreddit"
-                subreddits.append({"path": "https://old.reddit.com/r/" + path, "name": path})
+                path = f"https://old.reddit.com/r/{match}/"
+                subreddits.append({"path": path, "name": match})
             elif args.redditors:
                 ie_key = "reddit_praw_redditor"
-                redditors.append({"path": "https://old.reddit.com/user/" + path, "name": path})
+                path = f"https://old.reddit.com/user/{match}/"
+                redditors.append({"path": path, "name": match})
             else:
                 log.error(f"[{path}]: Skipping unknown URL")
                 continue
@@ -324,9 +360,8 @@ def reddit_add() -> None:
                 {
                     "path": path,
                     "id": match,
-                    "config": utils.get_config_opts(args, ["limit", "lookback", "praw_site"]),
-                    "category": args.category,
-                    "profile": args.profile,
+                    "config": utils.filter_namespace(args, ["limit", "lookback", "praw_site"]),
+                    "category": args.category or ie_key,
                     "ie_key": ie_key,
                     "time_deleted": 0,
                 }
@@ -335,23 +370,37 @@ def reddit_add() -> None:
             alter=True,
         )
 
-    skip_errors = (prawcore.exceptions.NotFound, prawcore.exceptions.Forbidden, prawcore.exceptions.Redirect)
-
-    for subreddit in subreddits:
-        try:
-            subreddit_new(args, subreddit)
-            subreddit_top(args, subreddit)
-        except skip_errors as e:
-            log.error("[%s] skipping subreddit: %s", subreddit["name"], e)
-            continue
-
-    for redditor in redditors:
-        try:
-            redditor_new(args, redditor)
-        except skip_errors as e:
-            log.error("[%s] skipping redditor: %s", redditor["name"], e)
-            continue
+    process_subreddits(args, subreddits)
+    process_redditors(args, redditors)
+    if not args.db["media"].detect_fts() or len(subreddits + redditors) > 75:
+        db.optimize(args)
 
 
-if __name__ == "__main__":
-    reddit_add()
+def reddit_update(args=None) -> None:
+    if args:
+        sys.argv[1:] = args
+
+    args = parse_args(
+        "redditupdate",
+        usage="""library redditupdate [--audio | --video] [-c CATEGORY] [--lookback N_DAYS] [--praw-site bot1] [database]
+
+    Fetch the latest posts for every subreddit/redditor saved in your database
+
+        library redditupdate edu_subreddits.db
+    """,
+    )
+    playlists = db.get_playlists(
+        args,
+        "ie_key, path, id, config",
+        sql_filters=['AND ie_key in ("reddit_praw_subreddit","reddit_praw_redditor")'],
+        constrain=True,
+    )
+
+    for playlist in playlists:
+        config = json.loads(playlist["config"])
+        args_env = args if not config else argparse.Namespace(**{**config, **args.__dict__})
+
+        if playlist["ie_key"] == "reddit_praw_subreddit":
+            process_subreddits(args_env, [{"path": playlist["path"], "name": playlist["id"]}])
+        elif playlist["ie_key"] == "reddit_praw_subreddit":
+            process_redditors(args_env, [{"path": playlist["path"], "name": playlist["id"]}])
