@@ -31,14 +31,6 @@ def parse_args(prog, usage):
     return args
 
 
-def get_playlists_join(args):
-    media_columns = args.db["media"].columns_dict
-    join = "(p.ie_key = media.ie_key = 'Local' and media.path like p.path || '%' ) "
-    if "playlist_path" in media_columns:
-        join += "or (p.ie_key = media.ie_key and media.ie_key != 'Local' and p.path = media.playlist_path)"
-    return join
-
-
 def construct_query(args) -> Tuple[str, dict]:
     pl_columns = args.db["playlists"].columns_dict
     cf = []
@@ -150,6 +142,7 @@ def playlists() -> None:
         return delete_playlists(args, args.delete)
 
     pl_columns = args.db["playlists"].columns_dict
+    m_columns = args.db["media"].columns_dict
     query, bindings = construct_query(args)
 
     query = f"""
@@ -162,15 +155,14 @@ def playlists() -> None:
             p.ie_key
             {', p.title' if 'title' in pl_columns else ''}
             , p.category
-            , p.profile
             , coalesce(p.path, "Playlist-less media") path
-            , sum(media.duration) duration
-            , sum(media.size) size
+            {', sum(media.duration) duration' if 'duration' in m_columns else ''}
+            {', sum(media.size) size' if 'size' in m_columns else ''}
             , count(*) count
         from media
-        left join ({query}) p on {get_playlists_join(args)}
+        left join ({query}) p on {db.get_playlists_join(args)}
         group by coalesce(p.path, "Playlist-less media")
-        order by category nulls last, profile, p.path"""
+        order by category nulls last, p.path"""
 
     printer(args, query, bindings)
 
@@ -183,27 +175,34 @@ def dlstatus() -> None:
     Print download queue groups
 
         library dlstatus video.db
-        ╒═════════════╤════════════════════╤═══════════╤═════════╤════════════════╕
-        │ ie_key      │ category           │ profile   │   count │ duration       │
-        ╞═════════════╪════════════════════╪═══════════╪═════════╪════════════════╡
-        │ Dailymotion │ 71_Mealtime_Videos │ video     │     277 │                │
-        ├─────────────┼────────────────────┼───────────┼─────────┼────────────────┤
-        │ Vimeo       │ 71_Mealtime_Videos │ video     │     442 │                │
-        ├─────────────┼────────────────────┼───────────┼─────────┼────────────────┤
-        │ Youtube     │ 71_Mealtime_Videos │ video     │   30185 │ 1 year, 3      │
-        │             │                    │           │         │ months, 7 days │
-        │             │                    │           │         │ and 15 hours   │
-        ├─────────────┼────────────────────┼───────────┼─────────┼────────────────┤
-        │ Dailymotion │ 75_MovieQueue      │ video     │      84 │                │
-        ├─────────────┼────────────────────┼───────────┼─────────┼────────────────┤
-        │ Vimeo       │ 75_MovieQueue      │ video     │      75 │                │
-        ├─────────────┼────────────────────┼───────────┼─────────┼────────────────┤
-        │ Youtube     │ 75_MovieQueue      │ video     │   20079 │ 8 months, 25   │
-        │             │                    │           │         │ days, 19 hours │
-        │             │                    │           │         │ and 18 minutes │
-        ╘═════════════╧════════════════════╧═══════════╧═════════╧════════════════╛
-""",
-    )
+        ╒═════════════════════╤═════════════╤══════════════════╤════════════════════╤══════════╕
+        │ category            │ ie_key      │ duration         │   never_downloaded │   errors │
+        ╞═════════════════════╪═════════════╪══════════════════╪════════════════════╪══════════╡
+        │ 71_Mealtime_Videos  │ Youtube     │ 3 hours and 2.07 │                 76 │        0 │
+        │                     │             │ minutes          │                    │          │
+        ├─────────────────────┼─────────────┼──────────────────┼────────────────────┼──────────┤
+        │ 75_MovieQueue       │ Dailymotion │                  │                 53 │        0 │
+        ├─────────────────────┼─────────────┼──────────────────┼────────────────────┼──────────┤
+        │ 75_MovieQueue       │ Youtube     │ 1 day, 18 hours  │                 30 │        0 │
+        │                     │             │ and 6 minutes    │                    │          │
+        ├─────────────────────┼─────────────┼──────────────────┼────────────────────┼──────────┤
+        │ Dailymotion         │ Dailymotion │                  │                186 │      198 │
+        ├─────────────────────┼─────────────┼──────────────────┼────────────────────┼──────────┤
+        │ Uncategorized       │ Youtube     │ 1 hour and 52.18 │                  1 │        0 │
+        │                     │             │ minutes          │                    │          │
+        ├─────────────────────┼─────────────┼──────────────────┼────────────────────┼──────────┤
+        │ Vimeo               │ Vimeo       │                  │                253 │       49 │
+        ├─────────────────────┼─────────────┼──────────────────┼────────────────────┼──────────┤
+        │ Youtube             │ Youtube     │ 2 years, 4       │              51676 │      197 │
+        │                     │             │ months, 15 days  │                    │          │
+        │                     │             │ and 6 hours      │                    │          │
+        ├─────────────────────┼─────────────┼──────────────────┼────────────────────┼──────────┤
+        │ Playlist-less media │ Youtube     │ 4 months, 23     │               2686 │        7 │
+        │                     │             │ days, 19 hours   │                    │          │
+        │                     │             │ and 33 minutes   │                    │          │
+        ╘═════════════════════╧═════════════╧══════════════════╧════════════════════╧══════════╛
+    """,
+        )
 
     if args.db:
         args.database = args.db
@@ -216,19 +215,18 @@ def dlstatus() -> None:
     m_columns = args.db["media"].columns_dict
     query, bindings = construct_query(args)
     query = f"""select
-        media.ie_key
-        , coalesce(p.category, "Playlist-less media") category
-        , p.profile
+        coalesce(p.category, "Playlist-less media") category
+        {', media.ie_key' if 'ie_key' in m_columns else ''}
+        {', sum(media.duration) duration' if 'duration' in m_columns else ''}
         , count(*) FILTER(WHERE time_modified=0) never_downloaded
-        , sum(media.duration) duration
         {', count(*) FILTER(WHERE time_modified>0 AND error IS NOT NULL) errors' if 'error' in m_columns else ''}
         --{', group_concat(distinct media.error) error_descriptions' if 'error' in m_columns else ''}
     from media
-    left join ({query}) p on {get_playlists_join(args)}
+    left join ({query}) p on {db.get_playlists_join(args)}
     where 1=1
         and media.time_downloaded=0
         and media.time_deleted=0
-    group by p.ie_key, p.category, p.profile
-    order by p.category nulls last, p.profile"""
+    group by p.ie_key, p.category
+    order by p.category nulls last"""
 
     printer(args, query, bindings)
