@@ -133,26 +133,6 @@ def is_supported(url) -> bool:  # thank you @dbr
     return False
 
 
-def get_playlists(args, cols="path, dl_config", constrain=False) -> List[dict]:
-    columns = args.db["playlists"].columns_dict
-    sql_filters = []
-    if "time_deleted" in columns:
-        sql_filters.append("AND time_deleted=0")
-    if constrain:
-        if args.category:
-            sql_filters.append(f"AND category='{args.category}'")
-        if args.profile:
-            sql_filters.append(f"AND profile='{args.profile}'")
-
-    try:
-        known_playlists = list(
-            args.db.query(f"select {cols} from playlists where 1=1 {' '.join(sql_filters)} order by random()")
-        )
-    except OperationalError:
-        known_playlists = []
-    return known_playlists
-
-
 def is_playlist_known(args, playlist_path) -> bool:
     try:
         known = args.db.execute("select 1 from playlists where path=?", [playlist_path]).fetchone()
@@ -255,7 +235,6 @@ def _add_playlist(args, playlist_path, pl: dict, media_path: Optional[str] = Non
         "dl_config": args.dl_config,
         "time_deleted": 0,
         "category": args.category or extractor,
-        "profile": args.profile,
         **args.extra_playlist_data,
     }
 
@@ -270,7 +249,6 @@ def save_undownloadable(args, playlist_path):
         "path": playlist_path,
         "title": "No data from ydl.extract_info",
         "category": args.category or "Uncategorized",
-        "profile": args.profile,
         "dl_config": args.dl_config,
         **args.extra_playlist_data,
     }
@@ -401,17 +379,17 @@ def update_playlists(args, playlists):
         process_playlist(
             args,
             d["path"],
-            tube_opts(args, playlist_opts=d["dl_config"], func_opts={"ignoreerrors": "only_download"}),
+            tube_opts(args, playlist_opts=d.get("dl_config", '{}'), func_opts={"ignoreerrors": "only_download"}),
         )
 
         if args.extra:
             log.warning("[%s]: Getting extra metadata", d["path"])
-            get_extra_metadata(args, d["path"], playlist_dl_opts=d["dl_config"])
+            get_extra_metadata(args, d["path"], playlist_dl_opts=d.get("dl_config", '{}'))
 
 
 def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False) -> None:
     webpath = m["path"]
-    error = None if not error else error.replace(m["id"], "").replace(" :", ":")
+    error = None if not error else error.replace(m.get("id",''), "").replace(" :", ":")
     if not info:  # not downloaded
         entry = {
             "path": webpath,
@@ -426,8 +404,8 @@ def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False)
     assert info["local_path"] != ""
     if Path(info["local_path"]).exists():
         fs_args = argparse.Namespace(
-            profile=m["profile"],
-            scan_subtitles=True if m["profile"] == DBType.video else False,
+            profile=args.profile,
+            scan_subtitles=True if args.profile == DBType.video else False,
             delete_unplayable=False,
             ocr=False,
             speech_recognition=False,
@@ -458,6 +436,9 @@ def save_tube_entry(args, m, info: Optional[dict] = None, error=None, URE=False)
 
 
 def yt(args, m) -> None:
+    if not m["path"].startswith("http"):
+        return
+
     ydl_log = {"warning": [], "error": []}
 
     class BadToTheBoneLogger:
@@ -496,13 +477,13 @@ def yt(args, m) -> None:
             "extractor_retries": 13,
             "retries": 13,
             "outtmpl": {
-                "default": out_dir("%(uploader|uploader_id)s/%(title).200B_[%(id).60B].%(ext)s"),
+                "default": out_dir("%(uploader,uploader_id)s/%(title).200B_[%(id).60B].%(ext)s"),
                 "chapter": out_dir(
-                    "%(uploader|uploader_id)s/%(title).200B_%(section_number)03d_%(section_title)s_[%(id).60B].%(ext)s"
+                    "%(uploader,uploader_id)s/%(title).200B_%(section_number)03d_%(section_title)s_[%(id).60B].%(ext)s"
                 ),
             },
         },
-        playlist_opts=m["dl_config"],
+        playlist_opts=m.get("dl_config", '{}'),
     )
 
     download_archive = Path("~/.local/share/yt_archive.txt").resolve()
@@ -514,12 +495,12 @@ def yt(args, m) -> None:
         ydl_opts["format"] = "bestvideo[height<=576]+bestaudio/best[height<=576]/best"
 
     if args.ext == "DEFAULT":
-        if m["profile"] == DBType.audio:
+        if args.profile == DBType.audio:
             args.ext = "opus"
         else:
             args.ext = None
 
-    if m["profile"] == DBType.audio:
+    if args.profile == DBType.audio:
         ydl_opts[
             "format"
         ] = "bestaudio[ext=opus]/bestaudio[ext=webm]/bestaudio[ext=ogg]/bestaudio[ext=oga]/bestaudio/best"
@@ -546,7 +527,7 @@ def yt(args, m) -> None:
             save_tube_entry(args, m, error="yt-dlp returned no info")
             return
 
-        if m["profile"] == DBType.audio:
+        if args.profile == DBType.audio:
             info["local_path"] = ydl.prepare_filename({**info, "ext": args.ext})
         else:
             info["local_path"] = ydl.prepare_filename(info)
